==> mindc-0.3-src.tar.bz2: mindc-0.3/adl-frontend/src/test/java/org/ow2/mind/adl/attribute/TestAttribute.java <==
/**
 * Copyright (C) 2010 STMicroelectronics
 *
 * This file is part of "Mind Compiler" is free software: you can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact: mind@ow2.org
 *
 * Authors: Matthieu Leclercq
 * Contributors: 
 */

package org.ow2.mind.adl.attribute;

import java.util.HashMap;
import java.util.Map;

import org.objectweb.fractal.adl.Definition;
import org.objectweb.fractal.adl.Loader;
import org.ow2.mind.CommonFrontendModule;
import org.ow2.mind.adl.ASTChecker;
import org.ow2.mind.adl.AbstractADLFrontendModule;
import org.ow2.mind.adl.BasicDefinitionReferenceResolver;
import org.ow2.mind.adl.CacheLoader;
import org.ow2.mind.adl.CachingDefinitionReferenceResolver;
import org.ow2.mind.adl.DefinitionReferenceResolver;
import org.ow2.mind.adl.ErrorLoader;
import org.ow2.mind.adl.ExtendsLoader;
import org.ow2.mind.adl.imports.ImportDefinitionReferenceResolver;
import org.ow2.mind.adl.parser.ADLParser;
import org.ow2.mind.plugin.PluginLoaderModule;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import com.google.inject.Guice;
import com.google.inject.Injector;

public class TestAttribute {

  Loader              loader;

  Map<Object, Object> context;

  ASTChecker          checker;

  @BeforeMethod(alwaysRun = true)
  protected void setUp() throws Exception {

    final Injector injector = Guice.createInjector(new CommonFrontendModule(),
        new PluginLoaderModule(), new AbstractADLFrontendModule() {

          protected void configureTest() {
            bind(Loader.class).toChainStartingWith(ErrorLoader.class)
                .followedBy(CacheLoader.class)
                .followedBy(AttributeCheckerLoader.class)
                .followedBy(AttributesNormalizerLoader.class)
                .followedBy(ExtendsLoader.class).endingWith(ADLParser.class);

            bind(DefinitionReferenceResolver.class)
                .toChainStartingWith(CachingDefinitionReferenceResolver.class)
                .followedBy(ImportDefinitionReferenceResolver.class)
                .endingWith(BasicDefinitionReferenceResolver.class);

            setDefaultExtendsLoaderConfig();
          }
        });

    loader = injector.getInstance(Loader.class);

    context = new HashMap<Object, Object>();

    checker = new ASTChecker();
  }

  @Test(groups = {"functional"})
  public void testAttr1() throws Exception {
    final Definition d = loader.load("pkg1.attr.Attr1", context);
    checker.assertDefinition(d).containsAttributes("attr1", "attr2", "attr3")
        .whereFirst().hasType("int").and().valueIs(12)

        .andNext().hasType("uint8_t").and().valueIs(11)

        .andNext().hasType("string").and().valueIs("toto");
  }

  @Test(groups = {"functional"})
  public void testExtendsAttr1() throws Exception {
    final Definition d = loader.load("pkg1.attr.ExtendsAttr1", context);
    checker.assertDefinition(d).containsAttributes("attr1", "attr2", "attr3")
        .whereFirst().hasType("int").and().valueReferences("a")

        .andNext().hasType("uint8_t").and().valueIs(11)

        .andNext().hasType("string").and().valueIs("titi");
  }
}

==> mindc-2.0-src.tar.bz2: mindc-2.0/adl-frontend/src/test/java/org/ow2/mind/adl/attribute/TestAttribute.java <==
/**
 * Copyright (C) 2010 STMicroelectronics
 *
 * This file is part of "Mind Compiler" is free software: you can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact: mind@ow2.org
 *
 * Authors: Matthieu Leclercq
 * Contributors: 
 */

package org.ow2.mind.adl.attribute;

import java.util.HashMap;
import java.util.Map;

import org.objectweb.fractal.adl.Definition;
import org.objectweb.fractal.adl.Loader;
import org.ow2.mind.CommonFrontendModule;
import org.ow2.mind.adl.ASTChecker;
import org.ow2.mind.adl.AbstractADLFrontendModule;
import org.ow2.mind.adl.BasicDefinitionReferenceResolver;
import org.ow2.mind.adl.CacheLoader;
import org.ow2.mind.adl.CachingDefinitionReferenceResolver;
import org.ow2.mind.adl.DefinitionReferenceResolver;
import org.ow2.mind.adl.ErrorLoader;
import org.ow2.mind.adl.ExtendsLoader;
import org.ow2.mind.adl.imports.ImportDefinitionReferenceResolver;
import org.ow2.mind.adl.parser.ADLParser;
import org.ow2.mind.idl.IDLFrontendModule;
import org.ow2.mind.plugin.PluginLoaderModule;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import com.google.inject.Guice;
import com.google.inject.Injector;

public class TestAttribute {

  Loader              loader;

  Map<Object, Object> context;

  ASTChecker          checker;

  @BeforeMethod(alwaysRun = true)
  protected void setUp() throws Exception {

    final Injector injector = Guice.createInjector(new CommonFrontendModule(),
        new PluginLoaderModule(), new IDLFrontendModule(),
        new AbstractADLFrontendModule() {

          protected void configureTest() {
            bind(Loader.class).toChainStartingWith(ErrorLoader.class)
                .followedBy(CacheLoader.class)
                .followedBy(AttributeCheckerLoader.class)
                .followedBy(AttributesNormalizerLoader.class)
                .followedBy(ExtendsLoader.class).endingWith(ADLParser.class);

            bind(DefinitionReferenceResolver.class)
                .toChainStartingWith(CachingDefinitionReferenceResolver.class)
                .followedBy(ImportDefinitionReferenceResolver.class)
                .endingWith(BasicDefinitionReferenceResolver.class);

            setDefaultExtendsLoaderConfig();
          }
        });

    loader = injector.getInstance(Loader.class);

    context = new HashMap<Object, Object>();

    checker = new ASTChecker();
  }

  @Test(groups = {"functional"})
  public void testAttr1() throws Exception {
    final Definition d = loader.load("pkg1.attr.Attr1", context);
    final Map<String, Object> attr5Value = new HashMap<String, Object>();
    attr5Value.put("s1", 6);
    attr5Value.put("s2", "titi");
    checker.assertDefinition(d)
        .containsAttributes("attr1", "attr2", "attr3", "attr4", "attr5")
        .whereFirst().hasType("int").and().valueIs(12)

        .andNext().hasType("uint8_t").and().valueIs(11)

        .andNext().hasType("string").and().valueIs("toto")

        .andNext().hasType("/pkg1/attr/foo.h:struct s")
        .valueIs(new Object[]{3, 5, new Object[]{4, 6}})

        .andNext().hasType("/pkg1/attr/foo.h:struct s").valueIs(attr5Value);
  }

  @Test(groups = {"functional"})
  public void testExtendsAttr1() throws Exception {
    final Definition d = loader.load("pkg1.attr.ExtendsAttr1", context);
    final Map<String, Object> attr5Value = new HashMap<String, Object>();
    attr5Value.put("s1", 6);
    attr5Value.put("s2", "titi");
    checker.assertDefinition(d)
        .containsAttributes("attr1", "attr2", "attr3", "attr4", "attr5")
        .whereFirst().hasType("int").and().valueReferences("a")

        .andNext().hasType("uint8_t").and().valueIs(11)

        .andNext().hasType("string").and().valueIs("titi")

        .andNext().hasType("/pkg1/attr/foo.h:struct s")
        .valueIs(new Object[]{3, 5, new Object[]{4, 6}})

        .andNext().hasType("/pkg1/attr/foo.h:struct s").valueIs(attr5Value);
  }
}
